==> kubernetes-model-certificates-6.8.1-sources.jar: io/fabric8/kubernetes/api/model/certificates/v1alpha1/ClusterTrustBundleSpecFluent.java <==
package io.fabric8.kubernetes.api.model.certificates.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ClusterTrustBundleSpecFluent<A extends ClusterTrustBundleSpecFluent<A>> extends BaseFluent<A>{
  public ClusterTrustBundleSpecFluent() {
  }
  public ClusterTrustBundleSpecFluent(ClusterTrustBundleSpec instance) {
    instance = (instance != null ? instance : new ClusterTrustBundleSpec());

    if (instance != null) {
      this.withSignerName(instance.getSignerName());
      this.withTrustBundle(instance.getTrustBundle());
      this.withSignerName(instance.getSignerName());
      this.withTrustBundle(instance.getTrustBundle());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String signerName;
  private String trustBundle;
  private Map<String,Object> additionalProperties;
  public String getSignerName() {
    return this.signerName;
  }
  public A withSignerName(String signerName) {
    this.signerName=signerName; return (A) this;
  }
  public boolean hasSignerName() {
    return this.signerName != null;
  }
  public String getTrustBundle() {
    return this.trustBundle;
  }
  public A withTrustBundle(String trustBundle) {
    this.trustBundle=trustBundle; return (A) this;
  }
  public boolean hasTrustBundle() {
    return this.trustBundle != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterTrustBundleSpecFluent that = (ClusterTrustBundleSpecFluent) o;
    if (!java.util.Objects.equals(signerName, that.signerName)) return false;

    if (!java.util.Objects.equals(trustBundle, that.trustBundle)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(signerName,  trustBundle,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (signerName != null) { sb.append("signerName:"); sb.append(signerName + ","); }
    if (trustBundle != null) { sb.append("trustBundle:"); sb.append(trustBundle + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> kubernetes-model-certificates-6.9.0-sources.jar: io/fabric8/kubernetes/api/model/certificates/v1alpha1/ClusterTrustBundleSpecFluent.java <==
package io.fabric8.kubernetes.api.model.certificates.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ClusterTrustBundleSpecFluent<A extends ClusterTrustBundleSpecFluent<A>> extends BaseFluent<A>{
  public ClusterTrustBundleSpecFluent() {
  }
  
  public ClusterTrustBundleSpecFluent(ClusterTrustBundleSpec instance) {
    this.copyInstance(instance);
  }
  private String signerName;
  private String trustBundle;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ClusterTrustBundleSpec instance) {
    instance = (instance != null ? instance : new ClusterTrustBundleSpec());
  
    if (instance != null) {
        this.withSignerName(instance.getSignerName());
        this.withTrustBundle(instance.getTrustBundle());
        this.withSignerName(instance.getSignerName());
        this.withTrustBundle(instance.getTrustBundle());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getSignerName() {
    return this.signerName;
  }
  
  public A withSignerName(String signerName) {
    this.signerName=signerName; return (A) this;
  }
  
  public boolean hasSignerName() {
    return this.signerName != null;
  }
  
  public String getTrustBundle() {
    return this.trustBundle;
  }
  
  public A withTrustBundle(String trustBundle) {
    this.trustBundle=trustBundle; return (A) this;
  }
  
  public boolean hasTrustBundle() {
    return this.trustBundle != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterTrustBundleSpecFluent that = (ClusterTrustBundleSpecFluent) o;
    if (!java.util.Objects.equals(signerName, that.signerName)) return false;
  
    if (!java.util.Objects.equals(trustBundle, that.trustBundle)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(signerName,  trustBundle,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (signerName != null) { sb.append("signerName:"); sb.append(signerName + ","); }
    if (trustBundle != null) { sb.append("trustBundle:"); sb.append(trustBundle + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
